*******************************************************************************
*PREPARES THE NELDA DATA ON ELECTIONS FOR FIGURE A6
*******************************************************************************
*1. Polity IV 2016 data
import excel "http://www.systemicpeace.org/inscr/p4v2016.xls",  firstrow clear
*cleaning up anomalies and duplications, combining some entries
replace ccode = 347 if country=="Kosovo"
*remove duplicate Yugoslavia 1991 entry
drop if cyear==3451991
*combine Yugoslavia pre 2003 with Serbia and Montenegro 2003-2006
replace ccode = 345 if country=="Yugoslavia"
replace ccode=345 if country=="Serbia and Montenegro"&year>2002&year<2007
replace ccode = 341 if country=="Montenegro"
*remove duplicate Ethiopia 1993 entry
drop if cyear==5291993
replace ccode=530 if country=="Ethiopia"
*consolidate Pakistan entries*
replace ccode=770 if country=="Pakistan"
*combine WG with Prussia and Germany with ccode = 255
drop if cyear==2601945
drop if cyear==2601990
replace ccode=255 if ccode==260
*combine USSR with Russia
drop if ccode==365&year==1922
replace ccode=365 if ccode==364
*correct error in Iran*
replace polity2=-9 if country=="Iran"&year==1979
replace polity2=-8 if country=="Iran"&year==1980
replace polity2=-7 if country=="Iran"&year==1981
*combine S Vietnam with Vietnam
replace ccode = 818 if ccode==816
*make consistent cyear
drop cyear
gen cyear = ccode*10000 + year
sort cyear
gen case=_n
tsset case
drop if cyear==f.cyear
drop case
*drop missing values
replace democ = . if democ<-10
replace autoc = . if autoc <-10
replace xrreg = . if xrreg <-10
replace xrcomp = . if xrcomp <-10
replace xropen = . if xropen <-10
replace xconst = . if xconst <-10
replace parreg = . if parreg <-10
replace parcomp = . if parcomp <-10
replace exrec = . if exrec <-10
replace exconst = . if exconst <-10
replace polcomp = . if polcomp<-10
replace polity2=. if polity<-10

xtset ccode year
by ccode: ipolate polity2 year, gen(pol3)
replace pol3=. if polity2==.&polity~=-77&polity~=-88
replace polity2=pol3

xtset ccode year
gen lpolity2 = l.polity2

*interpolate linearly to replace Polity's code for transitional or interregnum years (-88 and -77).
*We leave years of foreign occupation (polity = -66) as missing. Polity codes the interregnum years (polity=-77) as 0.
*This means that, for instance, during Afghanistan's civil war after 1991 the country's regime shot up to 0 from -8, only to fall back down
*to -7 when the Taliban took over. 
sort cyear
save "C:\Users\treis\Dropbox\Dictatorship\How Dictators Survive\Data June 2018\p4v2016.dta", replace

import delimited "C:\Users\treis\Dropbox\Dictatorship\How Dictators Survive\Data June 2018\NELDA.csv", clear
gen cyear= ccode*10000+year
sort cyear
merge m:1 cyear using "C:\Users\treis\Dropbox\Dictatorship\How Dictators Survive\Data June 2018\p4v2016.dta"

gen fiveyr = .
replace fiveyr=1945 if year>1944&year<1950
replace fiveyr=1950 if year>1949&year<1955
replace fiveyr=1955 if year>1954&year<1960
replace fiveyr=1960 if year>1959&year<1965
replace fiveyr=1965 if year>1964&year<1970
replace fiveyr=1970 if year>1969&year<1975
replace fiveyr=1975 if year>1974&year<1980
replace fiveyr=1980 if year>1979&year<1985
replace fiveyr=1985 if year>1984&year<1990
replace fiveyr=1990 if year>1989&year<1995
replace fiveyr=1995 if year>1994&year<2000
replace fiveyr=2000 if year>1999&year<2005
replace fiveyr=2005 if year>2004&year<2010
replace fiveyr=2010 if year>2009&year<2015

*nelda13 Were opposition leaders prevented from running?
*Note that this question is similar to nelda3 (was opposition allowed?), but is distinct in that it should be
*coded as “Yes” if any specific opposition party candidates are explicitly prevented from running. If nelda3
*is coded “No” this question is coded “N/A.” If nelda3 is “Yes” then this question is coded on a “Yes”/“No” basis.

gen nelda13a = nelda13
replace nelda13a="yes" if nelda13=="N/A"
label var nelda13a "yes: no oppo allowed or oppo ok but >=1 oppo cand. banned"

tab fiveyr nelda13a if lpolity2<6, row nofreq

*nelda15 Is there evidence that the government harassed the opposition?
*Harassment may include detaining opposition leaders, disrupting opposition political rallies with state forces, and shutting
*down opposition newspapers and offices. If opposition was banned, or if there was no opposition, (if nelda3
*is “No”) then an “N/A” was coded. Harassment of the opposition by the police can count as government harassment.

gen nelda15a = nelda15
replace nelda15a="" if nelda15=="N/A"
label var nelda15a "harassed oppo (in cases where was oppo)"
tab fiveyr nelda15a if lpolity2<6, row nofreq


*nelda16 In the run-up to the election, were there allegations of media bias in favor of the incumbent?
*If there were reports by either domestic or outside actors of media bias in favor of the incumbent or ruling
*party, it is coded as a “yes.” In cases where the media is totally controlled by the government, and/or no
*opposition is allowed, the answer is “yes.” It is possible that the answer is “No” even if the political system
*is tightly controlled.

gen nelda16a = nelda16
replace nelda16a="" if nelda16=="N/A"|nelda16=="unclear"
label var nelda16a "alleg. media bias % excluding N/A and unclear"
tab fiveyr nelda16a if lpolity2<6, row nofreq

*nelda45 Were international monitors present?
*International observers are typically invited by the host government and are organized or sponsored by
*international organizations or international non-governmental organizations. Because
*international election monitoring is a relatively recent phenomenon, source material before the 1990s may
*not mention whether international observers were present or not. Thus, before the 1990s, if no reference was
*made to international monitors, the questions should most likely be coded as “no.” If the source material is
*too sparse to make a judgment either way in the post-1990 period, unclear should be coded.

gen nelda45a = nelda45
replace nelda45a="" if nelda45=="N/A"|nelda45=="unclear"
label var nelda45a "int mons % excluding N/A and unclear"
tab fiveyr nelda45a if lpolity2<6, row nofreq


